@@ -1,5 +1,5 @@
 /* Special casing table.
-   Copyright (C) 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2009-2017 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2009.
 
    This program is free software: you can redistribute it and/or modify it
@@ -18,7 +18,7 @@
 #include <config.h>
 
 /* Specification.  */
-#include "special-casing.h"
+#include "unicase/special-casing.h"
 
 #include <string.h>
 
