@@ -1,5 +1,5 @@
 /* Casefolding mapping for UTF-8 substrings (locale dependent).
-   Copyright (C) 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2009-2017 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2009.
 
    This program is free software: you can redistribute it and/or modify it
@@ -25,7 +25,7 @@
 #include <stdlib.h>
 
 #include "unicasemap.h"
-#include "special-casing.h"
+#include "unicase/special-casing.h"
 #include "casefold.h"
 
 #define FUNC u8_ct_casefold
