@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2010, 2011, 2014 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ cmd_variable_labels (struct lexer *lexer, struct dataset *ds)
 	}
 
       for (i = 0; i < nv; i++)
-        var_set_label (v[i], lex_tokcstr (lexer), i == 0);
+        var_set_label (v[i], lex_tokcstr (lexer));
 
       lex_get (lexer);
       while (lex_token (lexer) == T_SLASH)
